@@ -1,13 +1,19 @@
-/* Prove that HANDLE_SYSTEMV_PRAGMA alignment handling works somewhat. */
+/* Prove that pragma alignment handling works somewhat. */
 
-/* { dg-do compile { target i?86-*-linux* i?86-*-*bsd* i?86-*-sco3.2v5* } } */
+/* { dg-do run } */
+
+extern void abort (void);
 
 struct {
         char one;
         long two;
 } defaultalign;
 
+#if defined(__LP64__)
+#pragma pack(8)
+#else
 #pragma pack(4)
+#endif
 struct {
         char one;
         long two;
@@ -39,4 +45,3 @@ main()
         if(sizeof(resetalign) != sizeof(defaultalign)) abort();
 	return 0;
 }
-
